Compute tree similarity
K2.RdCompute tree similarity
Arguments
- t1
A TreeHarp object.
- t2
A TreeHarp object.
- verbose
A logical value, indicating if the output should be verbose.
Value
An integer, that counts the number of sub-trees in common between the two trees. Please see the reference papers for more information.
Details
As far as possible, this function tries to do things recursively.
It sets up a n x m matrix and fills up as much as it can. Then it uses
recursive relationships to fill in the rest. When it cannot, it uses
generate_all_subtrees to generate and count common subtrees.