Given node names, this function retrieves the smallest tree containing at most
those nodes.
Usage
carve_mst(th, node_names)
Value
An object of class TreeHarp.
Arguments
th
An object of class TreeHarp.
node_names
A character vector of node names. Nodes outside this set
will not be returned in the tree. It must include the root node name.
Details
The function starts from each node specified and works it's way up
to the root. If a branch contains nodes outside the list, it is shortened.
In the end, the tree that is returned will try to contain all the named nodes,
but if that's not possible some will dropped to ensure a tree is returned,
not a disconnected graph.