Copy an object from one env to another.
copy_e2e.RdA wrapper function that uses assign and get.
Arguments
- from_obj
The name of the object to copy. It has to be a string.
- from_env
The environment in which the object lives. It has to be an object of class environment.
- to_obj
The name of the object to assign it to, in the new environment. Also a string.
- to_env
The environment to which the new object is to be assigned. It has to be an object of class environment.