Skip to contents

The generic method definition for getting adjacency list from a TreeHarp object.

Usage

get_adj_list(x, ...)

# S4 method for TreeHarp
get_adj_list(x, ...)

Arguments

x

An object of class TreeHarp.

...

Unused arguments, for now.

Value

The adjacency list for a TreeHarp object.

Methods (by class)

  • get_adj_list(TreeHarp): A getter.

    Allows user to extract the adjacency list of a treeharp object.