Get the children node ids
get_child_ids2.RdThis function retrieves the child node ids of a given node from an adjacency list of a tree.
Arguments
- adj_list
The adjacency list of the tree.
- at_node
The node whose children should be extracted.

get_child_ids2.RdThis function retrieves the child node ids of a given node from an adjacency list of a tree.
The adjacency list of the tree.
The node whose children should be extracted.