Get the id and depth of a child node.
get_next_depth_id.RdFrom the parent's depth and the last labelled node, we obtain the node id and depth of a child.

get_next_depth_id.RdFrom the parent's depth and the last labelled node, we obtain the node id and depth of a child.