Root a list of trees.
join_treeharps.RdGiven a list of trees, this will root them.
Details
This function combines TreeHarp objects into a single TreeHarp. The function will root all of them at a node called "script", which is neither a function call nor an argument nor a symbol. The BFS ordering is then updated.
Objects that are not of class TreeHarp will be dropped from the list before the rooting takes place.