Generate a dataframe from the log file.
log_summary.RdGenerate a dataframe from the log file.
Arguments
- log_file
The name of the log file generated from
render_one.
Details
This provides a table view of the log file, which is updated in a more natural format by simply concatenating new updates. The output of this function makes it easier to group entries by filename, time, or status, or even error message.
The output table does not contain correctness output. It only contains the columns name, timestamp, status (SUCCESS/FAIL), error message, number of libraries used and number of libraries installed.