Checks if two expressions differ only in terms of actual arguments
only_actual_args_differ.RdChecks if two expressions differ only in terms of actual arguments

only_actual_args_differ.RdChecks if two expressions differ only in terms of actual arguments