Extract a path from node to root.
path_to_root.RdIdentifies the nodes on the path from a node up to the root of a TreeHarp object.
Value
A vector of 1's and 0's that can be used to carve out the branch
alone, using carve_subtree.

path_to_root.RdIdentifies the nodes on the path from a node up to the root of a TreeHarp object.
A vector of 1's and 0's that can be used to carve out the branch
alone, using carve_subtree.