Conducts checks before rendering file
render_prechecks.RdThis routine conducts two checks before rendering the file: presence of View function, and presence of system() calls. The former is a nuisance, while the latter is possibly nefarious.

render_prechecks.RdThis routine conducts two checks before rendering the file: presence of View function, and presence of system() calls. The former is a nuisance, while the latter is possibly nefarious.