Learn R Programming

autoharp (version 0.2.0)

carve_subtree: Carve out branches to form a new tree.

Description

This functions keeps only the indicated nodes, returning a new sub-tree.

Usage

carve_subtree(obj, char_arr)

Value

An object of class TreeHarp.

Arguments

obj

An object of class TreeHarp.

char_arr

A vector of 1's and 0's indicating which nodes to keep. The vector should have length equal to the number of nodes in obj.

Details

This returns an error if the sub-tree does not define a new tree.

Examples

Run this code
th3 <- list(a= c(2L,3L,4L), b=NULL, c=c(5L, 6L), d=7L, e=NULL, f=NULL, g=NULL)
carve_subtree(TreeHarp(th3), c(1,0,0,0,0,0,0))
st <- subtree_at(TreeHarp(th3), 4)
plot(st)

Run the code above in your browser using DataLab