Check if a File is Rmd
check_rmd.RdChecks if a file actually is an Rmd file.
Arguments
- fname
A character string. It is the name of the student submission file.
- verbose
A logical value that prints messages if a non-rmd file is found.
Details
It runs three checks. First, it checks for the file extension to be Rmd or rmd or any such variant. Second, it checks for a YAML header at the beginning of file. Finally, it checks if there is at least one properly defined R chunk within the file.