Calculates the Total Memory Used
env_size.RdThis function uses the utils package to compute the total amount of memory used by objects in an environment.
Details
The names are wrapped in backticks. Otherwise, non-syntactic
names will cause problems. This function is used within
render_one as part of the runtime stats assessment.