powered by
Given two nodes that are on the same path to the root, this function determines the branch that leads to the child node.
find_branch_num(th, child_id, ancestor_id)
An integer that denotes the branch to follow down (from the ancestor) to reach the child.
A TreeHarp object.
An integer node id. It corresponds to the node to trace up from.
An integer node id. It corresponds to the node to trace down from.
This is used when trying to find a sub-call from a TreeHarp object. It is useful in determining the indices to use when extracting the sub-call.
ex3 <- quote(x <- f(y = g(3, 4), z=1L)) t1 <- TreeHarp(ex3, TRUE) find_branch_num(t1, 8, 3) # should be 1 find_branch_num(t1, 5, 3) # should be 2
Run the code above in your browser using DataLab