generate_all_subtrees: Generate all subtrees from a tree.
Description
This routines generates all subtrees rooted at the root node for a particular
tree.
Usage
generate_all_subtrees(th)
Value
A 0-1 matrix with n rows and m columns. n is the number of sub-trees
rooted at the root node of th. m is the number of nodes in this given tree.
The leading column will be a 1 for all the rows.
Arguments
th
An object of class TreeHarp.
References
Listing and counting subtrees of a tree, F Ruskey, SIAM Journal on Computing, 1981