get_adj_list.Rd
The generic method definition for getting adjacency list from a TreeHarp object.
get_adj_list(x, ...) # S4 method for TreeHarp get_adj_list(x, ...)
An object of class TreeHarp.
Unused arguments, for now.
The adjacency list for a TreeHarp object.
get_adj_list(TreeHarp): A getter.
get_adj_list(TreeHarp)
Allows user to extract the adjacency list of a treeharp object.