The generic method definition for getting child node ids.
get_child_ids(x, node_num)# S4 method for TreeHarp
get_child_ids(x, node_num)
# S4 method for list
get_child_ids(x, node_num)
An integer vector, indicating the children node ids.
An object of class TreeHarp.
An integer, length 1. This the node whose children we are after. If the specified node is a leaf, the NULL is returned.
get_child_ids(TreeHarp): Obtain child nodes.
Allows user to extract the child nodes from a specified node from TreeHarp object.
get_child_ids(list): Obtain child nodes.
Allows user to extract the child nodes from a specified node from an adjacency list.
get_parent_id