The generic method definition for getting node types from a
TreeHarp object.
Usage
get_node_types(x, ...)
# S4 method for TreeHarp
get_node_types(x, ...)
Arguments
- x
An object of class TreeHarp.
- ...
Unused arguments, for now.
Value
A data frame containing the node types for a TreeHarp object. If the
slot is empty, NA is returned.