When we need to go up the parse tree to obtain the function that
called this node, we use this function. It is similar to get_parent_id,
except that that function only returns the immediate parent.
It is not useful to call this function when the TreeHarp object is not
constructed from a language object.
Perhaps this function is necessary only because of the way language objects
are represented by the autoharp: formal arguments are included in the
tree representation. When we wish to find the calling function, we have to
walk up the branches till we reach a function call.