Convert language object to tree.
lang_2_tree.RdA recursive function for converting a language object to treeharp.
Arguments
- lang_obj
A language object.
- node_id
The calling node to this language object. This should only be greater than 0 if the
ni_envalready contains a partial adjacency list and corresponding node information. This will happen when this function is called recursively.- ni_env
An environment to store the adjacency list and node information.