Updates the node information regarding an R expression.
rbind_to_nodes_info(id, name, call_status, formal_arg, depth, env_ni)TRUE is returned invisibly.
The id of the node to be added. This should be an integer of length 1.
The name of the node.
Is the language object a call or a symbol/literal? This should a logical value.
Is the language object a formal argument or not? This should be a logical value.
An integer indicating the depth of this language object in the parse tree.
An environment object, possibly containing a data frame with columns id, name, call_status, formal_arg and depth.
This is for internal use. It may be removed from user-view soon!