Extract a sub-tree.
subtree_at.RdExtracts a sub-tree rooted at a particular node.
Arguments
- obj
An object of class TreeHarp
- at_node
The root of the new sub-tree. An integer, not a label, that corresponds to BFS indexing of the tree.
- preserve_call
A logical value that indicates if a sub-call should be extracted. This might be slower, but it allows you to evaluate it later.